//*************************************************************************
//* --------------------
//* CDCRawGPIBDatum Class
//* --------------------
//* (Description)
//* 	Classes for a single GPIB datum.
//* (Requires)
//*	TObject
//* (Provides)
//*	CDCRawGPIBDatum
//* (Update Record)
//*	1999/06/02  K.Fujii	Original version.
//*
//*************************************************************************


#include "JSFSteer.h"
#include "CDCRawGPIBDatum.h"
#include <iostream.h>

ClassImp(CDCRawGPIBDatum)

// static variables are not declared as constant so as to allow
// different formats in future.

Int_t CDCRawGPIBDatum::gFormatID  =  0;	// Format ID
Int_t CDCRawGPIBDatum::gNstabits  =  0;	// No. station number bits
Int_t CDCRawGPIBDatum::gNchabits  =  4;	// No. channel number bits
Int_t CDCRawGPIBDatum::gNswperdt  =  5;	// No. short words per GPIB datum
Int_t CDCRawGPIBDatum::gNchMax    =  1;	// Maximum GPIB channel No

//___________________________________________________________________________
// ------------
// Constructors
// ------------
//
CDCRawGPIBDatum::CDCRawGPIBDatum() 
	: fStationNo(0), fChannelNo(0), fGPIB(0)  {}
//___________________________________________________________________________
CDCRawGPIBDatum::CDCRawGPIBDatum(CDCRawGPIBDatum & rad) 
{
    fStationNo 	= rad.fStationNo;
    fChannelNo 	= rad.fChannelNo;
    fGPIB	= rad.fGPIB;
}

//___________________________________________________________________________
CDCRawGPIBDatum::CDCRawGPIBDatum(GPIB_t gpibword[])
{
    Unpack(gpibword);
}

//___________________________________________________________________________
// ------------
// Destructors
// ------------
//
CDCRawGPIBDatum::~CDCRawGPIBDatum() {}

//___________________________________________________________________________
// -------
// Setters
// -------
//
// This methods should be modified according to your raw data format.
//
void CDCRawGPIBDatum::SetFormat(CDCUniversalRecordHeader & urh)
{ 
    gFormatID = urh.GetFormatID();
    // set gNstabits, etc., according to the format ID.
    switch (gFormatID) {
        case 2: {
            gNstabits =  5;
            gNchabits =  4;
            gNchMax   =  1;
            break;
        }
        case 0: 
        case 1: 
        default: { 
            cerr << "CDCRawGPIBDatum::Unpack : Format ID = " << gFormatID
                 << " is not supported" << endl;
        }
    }
}

//___________________________________________________________________________
// ---------------
// Service Methods
// ---------------
//
// This methods should be modified according to your raw data format.
//
void CDCRawGPIBDatum::Unpack(GPIB_t gpibword[])
{
    switch (gFormatID) {
  	case 2: {
	   union { 
		Double_t d;
		UShort_t usi[4];
	   } tmpunion;
#ifndef __LITTLE_ENDIAN__
	   for (Int_t i=0; i<5; i++) {
           	gpibword[i] = (gpibword[i] << 8) | (gpibword[i] >> 8);
	   }
	   for (Int_t i=0; i<4; i++) tmpunion.usi[i] = gpibword[4-i];
#else
	   for (Int_t i=0; i<4; i++) tmpunion.usi[i] = gpibword[i+1];
#endif
  	   fStationNo = gpibword[0] >> (sizeof(GPIB_t)*8 - gNstabits);
  	   GPIB_t tmp = gpibword[0] << (sizeof(GPIB_t)*8 - gNchabits);
  	   fChannelNo = tmp >> (sizeof(GPIB_t)*8 - gNchabits);
  	   fGPIB      = tmpunion.d; 
#ifdef __DEBUG__
		cerr << "N,A,GPIBVal = " << fStationNo << " " << fChannelNo << " "
		     << fGPIB << endl;
#endif
	   break;
  	}
    	case 0: 
  	case 1:
        default: { 
            cerr << "CDCRawGPIBDatum::Unpack : Format ID = " << gFormatID
                 << " is not supported" << endl;
        }
    }
}

//___________________________________________________________________________
void CDCRawGPIBDatum::DebugPrint()
{
    cerr << " n " << fStationNo
         << " a " << fChannelNo
         << " val " << fGPIB << endl;
}
