#ifndef __CDCRAWSCALERDATUM__
#define __CDCRAWSCALERDATUM__

//*************************************************************************
//* --------------------
//* CDCRawScalerDatum Class
//* --------------------
//* (Description)
//* 	Classes for a single scaler datum.
//* (Requires)
//*	TObject
//* (Provides)
//*	CDCRawScalerDatum
//* (Update Record)
//*	1999/06/02  K.Fujii	Original version.
//*************************************************************************

#include "TObject.h"
#include "CDCUniversalRecordHeader.h"

// static variables are not declared as constant so as to allow
// different formats in future.

class CDCRawScalerDatum : public TObject {
public:
  CDCRawScalerDatum();
  CDCRawScalerDatum(CDCRawScalerDatum & rad);
  CDCRawScalerDatum(SCLR_t sclrword[]);
  virtual ~CDCRawScalerDatum();

  static void  SetFormat(CDCUniversalRecordHeader & urh);
  inline void  SetStationNo(Int_t n)    { fStationNo = n;    }
  inline void  SetChannelNo(Int_t n)    { fChannelNo = n;    }
  inline void  SetScaler   (Int_t n)    { fScaler    = n;    }
  
  inline Int_t    GetStationNo() const  { return fStationNo; }
  inline Int_t    GetChannelNo() const  { return fChannelNo; }
  inline Int_t    GetScaler   () const  { return fScaler;    }
  static Int_t    GetFormatID ()        { return gFormatID;  }
  static Int_t    GetRawLength()        { return gNswperdt;  }
  static Int_t    GetNchMax   ()        { return gNchMax;    }

  void Unpack(SCLR_t sclrword[]);
  void DebugPrint();

private:
  Int_t	   fStationNo;			// Station number
  Int_t    fChannelNo;			// Channel number
  Int_t    fScaler;	        	// Scaler value
  static   Int_t gFormatID;		//! Format ID
  static   Int_t gNstabits;		//! No. of bits for station No
  static   Int_t gNchabits;		//! No. of bits for channel No
  static   Int_t gNswperdt;		//! No. of short words per channel
  static   Int_t gNchMax;		//! Maximum channel No

  ClassDef(CDCRawScalerDatum, 1) // CDC raw data buffer
};

#endif
